@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2016                                                *
+ *  Copyright (c) 2001-2019                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -32,22 +32,154 @@ include_spip('inc/filtres_images_lib_mini'); // par precaution
  */
 function couleur_html_to_hex($couleur) {
 	$couleurs_html = array(
+		'aliceblue' => 'F0F8FF',
+		'antiquewhite' => 'FAEBD7',
 		'aqua' => '00FFFF',
+		'aquamarine' => '7FFFD4',
+		'azure' => 'F0FFFF',
+		'beige' => 'F5F5DC',
+		'bisque' => 'FFE4C4',
 		'black' => '000000',
+		'blanchedalmond' => 'FFEBCD',
 		'blue' => '0000FF',
+		'blueviolet' => '8A2BE2',
+		'brown' => 'A52A2A',
+		'burlywood' => 'DEB887',
+		'cadetblue' => '5F9EA0',
+		'chartreuse' => '7FFF00',
+		'chocolate' => 'D2691E',
+		'coral' => 'FF7F50',
+		'cornflowerblue' => '6495ED',
+		'cornsilk' => 'FFF8DC',
+		'crimson' => 'DC143C',
+		'cyan' => '00FFFF',
+		'darkblue' => '00008B',
+		'darkcyan' => '008B8B',
+		'darkgoldenrod' => 'B8860B',
+		'darkgray' => 'A9A9A9',
+		'darkgreen' => '006400',
+		'darkgrey' => 'A9A9A9',
+		'darkkhaki' => 'BDB76B',
+		'darkmagenta' => '8B008B',
+		'darkolivegreen' => '556B2F',
+		'darkorange' => 'FF8C00',
+		'darkorchid' => '9932CC',
+		'darkred' => '8B0000',
+		'darksalmon' => 'E9967A',
+		'darkseagreen' => '8FBC8F',
+		'darkslateblue' => '483D8B',
+		'darkslategray' => '2F4F4F',
+		'darkslategrey' => '2F4F4F',
+		'darkturquoise' => '00CED1',
+		'darkviolet' => '9400D3',
+		'deeppink' => 'FF1493',
+		'deepskyblue' => '00BFFF',
+		'dimgray' => '696969',
+		'dimgrey' => '696969',
+		'dodgerblue' => '1E90FF',
+		'firebrick' => 'B22222',
+		'floralwhite' => 'FFFAF0',
+		'forestgreen' => '228B22',
 		'fuchsia' => 'FF00FF',
+		'gainsboro' => 'DCDCDC',
+		'ghostwhite' => 'F8F8FF',
+		'gold' => 'FFD700',
+		'goldenrod' => 'DAA520',
 		'gray' => '808080',
 		'green' => '008000',
+		'greenyellow' => 'ADFF2F',
+		'grey' => '808080',
+		'honeydew' => 'F0FFF0',
+		'hotpink' => 'FF69B4',
+		'indianred' => 'CD5C5C',
+		'indigo' => '4B0082',
+		'ivory' => 'FFFFF0',
+		'khaki' => 'F0E68C',
+		'lavender' => 'E6E6FA',
+		'lavenderblush' => 'FFF0F5',
+		'lawngreen' => '7CFC00',
+		'lemonchiffon' => 'FFFACD',
+		'lightblue' => 'ADD8E6',
+		'lightcoral' => 'F08080',
+		'lightcyan' => 'E0FFFF',
+		'lightgoldenrodyellow' => 'FAFAD2',
+		'lightgray' => 'D3D3D3',
+		'lightgreen' => '90EE90',
+		'lightgrey' => 'D3D3D3',
+		'lightpink' => 'FFB6C1',
+		'lightsalmon' => 'FFA07A',
+		'lightseagreen' => '20B2AA',
+		'lightskyblue' => '87CEFA',
+		'lightslategray' => '778899',
+		'lightslategrey' => '778899',
+		'lightsteelblue' => 'B0C4DE',
+		'lightyellow' => 'FFFFE0',
 		'lime' => '00FF00',
+		'limegreen' => '32CD32',
+		'linen' => 'FAF0E6',
+		'magenta' => 'FF00FF',
 		'maroon' => '800000',
+		'mediumaquamarine' => '66CDAA',
+		'mediumblue' => '0000CD',
+		'mediumorchid' => 'BA55D3',
+		'mediumpurple' => '9370DB',
+		'mediumseagreen' => '3CB371',
+		'mediumslateblue' => '7B68EE',
+		'mediumspringgreen' => '00FA9A',
+		'mediumturquoise' => '48D1CC',
+		'mediumvioletred' => 'C71585',
+		'midnightblue' => '191970',
+		'mintcream' => 'F5FFFA',
+		'mistyrose' => 'FFE4E1',
+		'moccasin' => 'FFE4B5',
+		'navajowhite' => 'FFDEAD',
 		'navy' => '000080',
+		'oldlace' => 'FDF5E6',
 		'olive' => '808000',
+		'olivedrab' => '6B8E23',
+		'orange' => 'FFA500',
+		'orangered' => 'FF4500',
+		'orchid' => 'DA70D6',
+		'palegoldenrod' => 'EEE8AA',
+		'palegreen' => '98FB98',
+		'paleturquoise' => 'AFEEEE',
+		'palevioletred' => 'DB7093',
+		'papayawhip' => 'FFEFD5',
+		'peachpuff' => 'FFDAB9',
+		'peru' => 'CD853F',
+		'pink' => 'FFC0CB',
+		'plum' => 'DDA0DD',
+		'powderblue' => 'B0E0E6',
 		'purple' => '800080',
+		'rebeccapurple' => '663399',
 		'red' => 'FF0000',
+		'rosybrown' => 'BC8F8F',
+		'royalblue' => '4169E1',
+		'saddlebrown' => '8B4513',
+		'salmon' => 'FA8072',
+		'sandybrown' => 'F4A460',
+		'seagreen' => '2E8B57',
+		'seashell' => 'FFF5EE',
+		'sienna' => 'A0522D',
 		'silver' => 'C0C0C0',
+		'skyblue' => '87CEEB',
+		'slateblue' => '6A5ACD',
+		'slategray' => '708090',
+		'slategrey' => '708090',
+		'snow' => 'FFFAFA',
+		'springgreen' => '00FF7F',
+		'steelblue' => '4682B4',
+		'tan' => 'D2B48C',
 		'teal' => '008080',
+		'thistle' => 'D8BFD8',
+		'tomato' => 'FF6347',
+		'turquoise' => '40E0D0',
+		'violet' => 'EE82EE',
+		'wheat' => 'F5DEB3',
 		'white' => 'FFFFFF',
-		'yellow' => 'FFFF00'
+		'whitesmoke' => 'F5F5F5',
+		'yellow' => 'FFFF00',
+		'yellowgreen' => '9ACD32',
 	);
 	if (isset($couleurs_html[$lc = strtolower($couleur)])) {
 		return $couleurs_html[$lc];
@@ -71,9 +203,9 @@ function couleur_html_to_hex($couleur) {
 function couleur_foncer($couleur, $coeff = 0.5) {
 	$couleurs = _couleur_hex_to_dec($couleur);
 
-	$red = $couleurs["red"] - round(($couleurs["red"]) * $coeff);
-	$green = $couleurs["green"] - round(($couleurs["green"]) * $coeff);
-	$blue = $couleurs["blue"] - round(($couleurs["blue"]) * $coeff);
+	$red = $couleurs['red'] - round(($couleurs['red']) * $coeff);
+	$green = $couleurs['green'] - round(($couleurs['green']) * $coeff);
+	$blue = $couleurs['blue'] - round(($couleurs['blue']) * $coeff);
 
 	$couleur = _couleur_dec_to_hex($red, $green, $blue);
 
@@ -95,14 +227,13 @@ function couleur_foncer($couleur, $coeff = 0.5) {
 function couleur_eclaircir($couleur, $coeff = 0.5) {
 	$couleurs = _couleur_hex_to_dec($couleur);
 
-	$red = $couleurs["red"] + round((255 - $couleurs["red"]) * $coeff);
-	$green = $couleurs["green"] + round((255 - $couleurs["green"]) * $coeff);
-	$blue = $couleurs["blue"] + round((255 - $couleurs["blue"]) * $coeff);
+	$red = $couleurs['red'] + round((255 - $couleurs['red']) * $coeff);
+	$green = $couleurs['green'] + round((255 - $couleurs['green']) * $coeff);
+	$blue = $couleurs['blue'] + round((255 - $couleurs['blue']) * $coeff);
 
 	$couleur = _couleur_dec_to_hex($red, $green, $blue);
 
 	return $couleur;
-
 }
 
 /**
@@ -137,12 +268,12 @@ function image_select($img, $width_min = 0, $height_min = 0, $width_max = 10000,
 	$class = extraire_attribut($img, 'class');
 	$p = strpos($class, 'filtre_inactif');
 	if (($select == false) and ($p === false)) {
-		$class .= " filtre_inactif";
+		$class .= ' filtre_inactif';
 		$img = inserer_attribut($img, 'class', $class);
 	}
 	if (($select == true) and ($p !== false)) {
 		// no_image_filtrer : historique, a virer
-		$class = preg_replace(",\s*(filtre_inactif|no_image_filtrer),", "", $class);
+		$class = preg_replace(',\s*(filtre_inactif|no_image_filtrer),', '', $class);
 		$img = inserer_attribut($img, 'class', $class);
 	}
 
@@ -225,7 +356,7 @@ function image_passe_partout(
 	list($destWidth, $destHeight, $ratio) = ratio_passe_partout($largeur, $hauteur, $taille_x, $taille_y);
 	$fonction = array('image_passe_partout', func_get_args());
 
-	return process_image_reduire($fonction, $img, $destWidth, $destHeight, $force, $cherche_image, $process);
+	return process_image_reduire($fonction, $img, $destWidth, $destHeight, $force, $process);
 }
 
 /**
@@ -289,7 +420,7 @@ function image_reduire($img, $taille = -1, $taille_y = -1, $force = false, $cher
 
 	$fonction = array('image_reduire', func_get_args());
 
-	return process_image_reduire($fonction, $img, $taille, $taille_y, $force, $cherche_image, $process);
+	return process_image_reduire($fonction, $img, $taille, $taille_y, $force, $process);
 }
 
 
@@ -323,3 +454,51 @@ function image_reduire_par($img, $val = 1, $force = false) {
 
 	return $img;
 }
+
+/**
+ * Modifie la saturation de la couleur transmise
+ *
+ * @note
+ *     Nécessite le plugin `filtres_images` pour fonctionner.
+ *     La couleur d’entrée est retournée tel quelle en cas d'absence.
+ * 
+ * @see couleur_saturation() du plugin `filtres_images`
+ * @uses couleur_saturation()
+ * 
+ * @param string $couleur
+ *      Couleur en écriture hexadécimale, tel que `ff3300`
+ * @param float $val
+ *      Pourcentage désiré (entre 0 et 1)
+ * @return string
+ *      Couleur en écriture hexadécimale.
+**/
+function filtre_couleur_saturation_dist($couleur, $val) {
+	if (function_exists('couleur_saturation')) {
+		return couleur_saturation($couleur, $val);
+	}
+	return $couleur;
+}
+
+/**
+ * Modifie la luminance de la couleur transmise
+ *
+ * @note
+ *     Nécessite le plugin `filtres_images` pour fonctionner.
+ *     La couleur d’entrée est retournée tel quelle en cas d'absence.
+ * 
+ * @see couleur_luminance() du plugin `filtres_images`
+ * @uses couleur_luminance()
+ * 
+ * @param string $couleur
+ *      Couleur en écriture hexadécimale, tel que `ff3300`
+ * @param float $val
+ *      Pourcentage désiré (entre 0 et 1)
+ * @return string
+ *      Couleur en écriture hexadécimale.
+**/
+function filtre_couleur_luminance_dist($couleur, $val) {
+	if (function_exists('couleur_luminance')) {
+		return couleur_luminance($couleur, $val);
+	}
+	return $couleur;
+}
