@@ -1,6 +1,6 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=en
+// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=en
 // ** ne pas modifier le fichier **
 
 if (!defined('_ECRIRE_INC_VERSION')) {
@@ -31,7 +31,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_3' => 'Alternatively, do not use LDAP support to import users.',
 	'avis_deplacement_rubrique' => 'Warning! This section contains @contient_breves@ news item@scb@: if you move it, please check this box to confirm.',
 	'avis_erreur_connexion_mysql' => 'SQL connection error',
-	'avis_espace_interdit' => '<b>Forbidden area</b><div>SPIP is already installed.</div>',
+	'avis_espace_interdit' => '<b>Forbidden area</b> <div>SPIP is already installed.</div>',
 	'avis_lecture_noms_bases_1' => 'The installer could not read the names of any databases already installed.',
 	'avis_lecture_noms_bases_2' => 'Either no database is available, or the option for listing databases was disabled for security reasons (which is the case with a lot of hosting services).',
 	'avis_lecture_noms_bases_3' => 'In the second case, it is possible that a database named after your login would be usable:',
@@ -61,7 +61,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Do not appear in the list of editors online',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Do not send any editorial announcements',
 	'bouton_redirection' => 'REDIRECT',
+	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Reset to default values',
 	'bouton_relancer_installation' => 'Recommence installation',
+	'bouton_reset_password' => 'Create a new password and send by e-mail',
 	'bouton_suivant' => 'Next',
 	'bouton_tenter_recuperation' => 'Attempt to repair',
 	'bouton_test_proxy' => 'Test the proxy',
@@ -133,6 +135,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_url' => 'URL of your site',
 	'entree_url_2' => 'Site URL',
 	'erreur_connect_deja_existant' => 'There is already a server with that name ',
+	'erreur_contenu_suspect' => 'Text badly formatted',
 	'erreur_email_deja_existant' => 'This email address is already registered.',
 	'erreur_nom_connect_incorrect' => 'Server name not allowed',
 	'erreur_plugin_attribut_balise_manquant' => 'Attribut @attribut@ fehlt in dem tag @balise@',
@@ -501,6 +504,7 @@ and their status is colour-coded:',
 	'info_une_rubrique_02' => '1 section',
 	'info_url' => 'URL:',
 	'info_url_proxy' => 'Proxy URL',
+	'info_url_proxy_pas_conforme' => 'Proxy’s URL not valid.',
 	'info_url_site_pas_conforme' => 'the website URL is invalid.',
 	'info_url_test_proxy' => 'Test URL',
 	'info_urlref' => 'Hyperlink:',
@@ -589,6 +593,9 @@ and their status is colour-coded:',
 	'lien_ajouter_une_rubrique' => 'Add this section',
 	'lien_email' => 'email',
 	'lien_nom_site' => 'SITE NAME:',
+	'lien_rapide_contenu' => 'Go to the content',
+	'lien_rapide_navigation' => 'Go to the navigation',
+	'lien_rapide_recherche' => 'Go to the search',
 	'lien_retirer_auteur' => 'Remove author',
 	'lien_retirer_rubrique' => 'Remove the section',
 	'lien_retirer_tous_auteurs' => 'Remove all authors',
@@ -634,6 +641,7 @@ and their status is colour-coded:',
 	// P
 	'page_pas_proxy' => 'This page must not go through the proxy',
 	'pas_de_proxy_pour' => 'If necessary, indicate to which machines or domains this proxy should not apply (for example: @exemple@)',
+	'phpinfo' => 'PHP configuration',
 	'plugin_charge_paquet' => 'Loading the archive file @name@',
 	'plugin_charger' => 'Download',
 	'plugin_erreur_charger' => 'error: @zip@ cannot be loaded',
@@ -668,7 +676,10 @@ and their status is colour-coded:',
 	'plugin_info_telecharger' => 'load from @url@ and install to @rep@',
 	'plugin_info_upgrade_ok' => 'Successful update',
 	'plugin_librairies_installees' => 'Libraries installed',
+	'plugin_necessite_extension_php' => 'Requires the PHP extension @plugin@ version @version@.',
+	'plugin_necessite_extension_php_sans_version' => 'Requires the PHP extension @plugin@',
 	'plugin_necessite_lib' => 'This plugin requires the library @lib@',
+	'plugin_necessite_php' => 'Requires @plugin@ version @version@.',
 	'plugin_necessite_plugin' => 'Version @version@ of the plugin @plugin@ is required.',
 	'plugin_necessite_plugin_sans_version' => 'Requires the plugin @plugin@',
 	'plugin_necessite_spip' => 'SPIP version @version@ or newer is required.',
@@ -677,6 +688,8 @@ and their status is colour-coded:',
 	'plugin_titre_automatique_ajouter' => 'Add plugins',
 	'plugin_titre_installation' => 'Installation of the @plugin@ plugin',
 	'plugin_titre_modifier' => 'My plugins',
+	'plugin_utilise_extension_php' => 'Uses the PHP extension @plugin@ version @version@.',
+	'plugin_utilise_php' => 'Uses @plugin@ version @version@.',
 	'plugin_utilise_plugin' => 'Utilise le plugin @plugin@ en version @version@.',
 	'plugin_zip_active' => 'Continue in order to activate',
 	'plugin_zip_adresse' => 'To load a zipped plugin file, or a list of plugins, enter the path below.',
@@ -869,6 +882,7 @@ significant modifications to the site’s graphics or structure.',
 	'titre_config_langage' => 'Configure the language',
 	'titre_configuration' => 'Site configuration',
 	'titre_configurer_preferences' => 'Configure your preferences',
+	'titre_configurer_preferences_menus' => 'Settings of your menus preferences',
 	'titre_conflit_edition' => 'Conflict while editing',
 	'titre_connexion_ldap' => 'Options: <b>Your LDAP connection</b>',
 	'titre_groupe_mots' => 'KEYWORD GROUP:',
@@ -890,6 +904,7 @@ significant modifications to the site’s graphics or structure.',
 	'titre_page_recherche' => 'Search results @recherche@',
 	'titre_page_statistiques_referers' => 'Statistics (incoming links)',
 	'titre_page_upgrade' => 'SPIP upgrade',
+	'titre_preference_menus_favoris' => 'Favourites menu',
 	'titre_publication_articles_post_dates' => 'Publication of post dated articles',
 	'titre_reparation' => 'Repair',
 	'titre_suivi_petition' => 'Petitions follow-up',
@@ -905,5 +920,3 @@ significant modifications to the site’s graphics or structure.',
 	// V
 	'version' => 'Version:'
 );
-
-?>
