@@ -1,6 +1,6 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=vi
+// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=vi
 // ** ne pas modifier le fichier **
 
 if (!defined('_ECRIRE_INC_VERSION')) {
@@ -24,7 +24,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_ldap_echec_3' => 'Một cách khác, đừng dùng LDAP support để đem tên người dùng vào.',
 	'avis_deplacement_rubrique' => 'LƯU Ý! Đề mục này chứa @contient_breves@ các tin ngắn @scb@: nếu bạn dời nó đi, xin đánh dấu vào ô này để xác nhận.',
 	'avis_erreur_connexion_mysql' => 'Có Lỗi-không nối với SQL',
-	'avis_espace_interdit' => '<b>Vùng cấm địa</b><p>SPIP đã được thiết trí rồi.',
+	'avis_espace_interdit' => '<b>Vùng cấm địa</b><p>SPIP đã được thiết trí rồi.', # MODIF
 	'avis_lecture_noms_bases_1' => 'Nhu liệu thiết trí không đọc được tên của database thiết trí.',
 	'avis_lecture_noms_bases_2' => 'Không có database nào hết, hoặc đặc điểm cho phép liệt kê tên database bị tắt đi vì lý do an ninh (thường là như vậy cho nhiều máy chủ)',
 	'avis_lecture_noms_bases_3' => 'Trong trường hợp lựa chọn thứ nhì xảy ra, sau khi bạn login vào, có thể một database có tên lúc đó có thể dùng được: ',
@@ -549,5 +549,3 @@ Bạn có thể cho phép cảnh báo hay không:',
 	'trad_lier' => 'Bài này là bản dịch của bài số',
 	'trad_new' => 'Dịch bài này' # MODIF
 );
-
-?>
