@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2016                                                *
+ *  Copyright (c) 2001-2019                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -15,7 +15,7 @@
  *
  * @package SPIP\Compresseur\Formulaires
  **/
-if (!defined("_ECRIRE_INC_VERSION")) {
+if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
@@ -31,7 +31,6 @@ function formulaires_configurer_compresseur_charger_dist() {
 
 	$valeurs['auto_compress_js'] = $GLOBALS['meta']['auto_compress_js'];
 	$valeurs['auto_compress_css'] = $GLOBALS['meta']['auto_compress_css'];
-	$valeurs['auto_compress_closure'] = $GLOBALS['meta']['auto_compress_closure'];
 	$valeurs['url_statique_ressources'] = $GLOBALS['meta']['url_statique_ressources'];
 
 	return $valeurs;
@@ -48,20 +47,20 @@ function formulaires_configurer_compresseur_verifier_dist() {
 	$erreurs = array();
 
 	// les checkbox
-	foreach (array('auto_compress_js', 'auto_compress_css', 'auto_compress_closure') as $champ) {
+	foreach (array('auto_compress_js', 'auto_compress_css') as $champ) {
 		if (_request($champ) != 'oui') {
 			set_request($champ, 'non');
 		}
 	}
 
-	if ($url = _request('url_statique_ressources')){
-		$url = preg_replace(",/?\s*$,", "", $url);
+	if ($url = _request('url_statique_ressources')) {
+		$url = preg_replace(',/?\s*$,', '', $url);
 		if (!tester_url_absolue($url)) {
-			$protocole = explode('://',$GLOBALS['meta']['adresse_site']);
+			$protocole = explode('://', $GLOBALS['meta']['adresse_site']);
 			$protocole = reset($protocole);
 			$url = $protocole . "://$url";
 		}
-		set_request('url_statique_ressources',$url);
+		set_request('url_statique_ressources', $url);
 	}
 
 
