@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2016                                                *
+ *  Copyright (c) 2001-2019                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) {
+if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
@@ -25,7 +25,7 @@ include_spip('inc/dump');
  * @return bool
  */
 function inc_sauvegarder_dist($status_file, $redirect = '') {
-	$status_file = _DIR_TMP . basename($status_file) . ".txt";
+	$status_file = _DIR_TMP . basename($status_file) . '.txt';
 	if (!lire_fichier($status_file, $status)
 		or !$status = unserialize($status)
 	) {
@@ -38,14 +38,14 @@ function inc_sauvegarder_dist($status_file, $redirect = '') {
 		$max_time = time() + $timeout / 2;
 
 		include_spip('inc/minipres');
-		@ini_set("zlib.output_compression", "0"); // pour permettre l'affichage au fur et a mesure
+		@ini_set('zlib.output_compression', '0'); // pour permettre l'affichage au fur et a mesure
 
-		$titre = _T('dump:sauvegarde_en_cours') . " (" . count($status['tables']) . ") ";
+		$titre = _T('dump:sauvegarde_en_cours') . ' (' . count($status['tables']) . ') ';
 		$balise_img = chercher_filtre('balise_img');
 		$titre .= $balise_img(chemin_image('searching.gif'));
 		echo(install_debut_html($titre));
 		// script de rechargement auto sur timeout
-		echo http_script("window.setTimeout('location.href=\"" . $redirect . "\";'," . ($timeout * 1000) . ")");
+		echo http_script("window.setTimeout('location.href=\"" . $redirect . "\";'," . ($timeout * 1000) . ')');
 		echo "<div style='text-align: left'>\n";
 
 		dump_serveur($status['connect']);
@@ -69,7 +69,9 @@ function inc_sauvegarder_dist($status_file, $redirect = '') {
 			echo dump_relance($redirect);
 		}
 		echo(install_fin_html());
-		ob_end_flush();
+		if (@ob_get_contents()) {
+			ob_end_flush();
+		}
 		flush();
 
 		return $res;
