@@ -1,6 +1,6 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=bs
+// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=bs
 // ** ne pas modifier le fichier **
 
 if (!defined('_ECRIRE_INC_VERSION')) {
@@ -25,7 +25,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'forum' => 'Forum',
 	'forum_acces_refuse' => 'Nemate vise pristup ovim forumima.',
 	'forum_attention_dix_caracteres' => '<b>Upozorenje!</b> Vasa poruka mora sadrzati najmanje deset karaktera.',
-	'forum_attention_trois_caracteres' => '<b>Upozorenje!</b> Vas naslov mora sadrzati najmanje tri karaktera.',
+	'forum_attention_trois_caracteres' => '<b>Upozorenje!</b> Vaš naslov mora imati najmanje tri karaktera.',
 	'forum_avez_selectionne' => 'Izabrali ste:',
 	'forum_cliquer_retour' => 'Kliknite <a href=\'@retour_forum@\'>ici</a> da bi ste nastavili.',
 	'forum_forum' => 'forum',
@@ -91,5 +91,3 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_forum_suivi' => 'Pracenje foruma',
 	'titre_page_forum_suivi' => 'Pracenje foruma'
 );
-
-?>
