@@ -1,6 +1,6 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de http://trad.spip.net/tradlang_module/forum?lang_cible=eu
+// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=eu
 // ** ne pas modifier le fichier **
 
 if (!defined('_ECRIRE_INC_VERSION')) {
@@ -15,31 +15,34 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// B
 	'bouton_radio_articles_futurs' => 'geroko artikuluei soilik (ez du aldatzen datu-basea).',
 	'bouton_radio_articles_tous' => 'artikulu guztiei, salbuespenik gabe.',
-	'bouton_radio_articles_tous_sauf_forum_desactive' => 'artikuluguztiei, desaktibatutako foroan daudenei izan ezik.',
+	'bouton_radio_articles_tous_sauf_forum_desactive' => 'artikulu guztiei, desaktibatutako foroan daudenei izan ezik.',
 	'bouton_radio_enregistrement_obligatoire' => 'Izena ematea derrigorrezkoa da (foroan parte hartu ahal izateko, inskripzioa egin behar da posta elektronikoaren helbidea emanez).',
 	'bouton_radio_moderation_priori' => 'Aurretiaz moderatua (ekarpenak agerian egongodira lekuaren administrazio-eskubideak dituen pertsona batek onartu eta gero).',
 	'bouton_radio_modere_abonnement' => 'Moderatua (harpidedunentzat soilik)',
 	'bouton_radio_modere_posteriori' => 'gerora moderatua',
 	'bouton_radio_modere_priori' => 'aurretiaz moderatua',
-	'bouton_radio_publication_immediate' => 'Mezuen bat-bateko argitaratzea (erakarpenak agerian egongo dira igorri bezain laister, gero administraziotik kendu daitezke).',
+	'bouton_radio_publication_immediate' => 'Iruzkinen bat-bateko argitaratzea (erakarpenak agerian egongo dira igorri bezain laister, gero administraziotik kendu daitezke).',
 
 	// D
 	'documents_interdits_forum' => 'Dokumentuak debekatuak dira foroetan',
 
 	// E
-	'erreur_enregistrement_message' => 'Zure mezuaren garbaketak huts egin du, akats tekniko batengatik',
+	'erreur_enregistrement_message' => 'Zure iruzkinaren garbaketak huts egin du, akats tekniko batengatik',
+	'extensions_autorisees' => 'Baimendutako fitxategien atzizkia:',
+	'extensions_autorisees_toutes' => 'guztiak',
 
 	// F
-	'form_pet_message_commentaire' => 'Mezurik, azalpenik ?',
+	'form_pet_message_commentaire' => 'Mezurik, iruzkinik ?',
 	'forum' => 'Foroa',
 	'forum_acces_refuse' => 'Dagoeneko ezin zara foro hauetan sartu.',
-	'forum_attention_dix_caracteres' => '<b>Adi!</b> zure mezuak hamar karaktere baino gutxiago ditu',
+	'forum_attention_dix_caracteres' => '<b>Adi!</b> zure iruzkinak hamar karaktere baino gutxiago ditu',
 	'forum_attention_message_non_poste' => 'Kontuz, mezua ez duzu igorria !',
-	'forum_attention_nb_caracteres_mini' => '<b>Kontuz !</b> zure mezuak @min@ karaketre bederen eduki behar ditu.',
+	'forum_attention_nb_caracteres_mini' => '<b>Adi!</b> zure mezuak @min@ karaketre bederen eduki behar ditu.',
 	'forum_attention_trois_caracteres' => '<b>Adi!</b> zure izenburuak hiru karaktere baino gutxiago ditu.',
-	'forum_attention_trop_caracteres' => '<b>kontuz !</b> zure mezua luzeegi da (@compte@ caractères) : grabatua izateko, ez ditu @max@ karaktero baino gehiago izan behar.',
+	'forum_attention_trop_caracteres' => '<b>Adi!</b> zure mezua luzeegi da (@compte@ caractères) : grabatua izateko, ez ditu @max@ karaktero baino gehiago izan behar.',
 	'forum_avez_selectionne' => 'Aukeratu egin duzu:',
 	'forum_cliquer_retour' => 'Jarraitzeko hemen klik egin.',
+	'forum_envoyer' => 'Bidali',
 	'forum_forum' => 'foroa',
 	'forum_info_modere' => 'Foro hau aurretiaz moderaturik dago : 
 Zure ekarpena gunearen administratzaileak onartu ondoren soilik agerian izango da.',
@@ -55,9 +58,9 @@ Zure ekarpena gunearen administratzaileak onartu ondoren soilik agerian izango d
 	'forum_poste_par_generique' => 'Iruzkina igorria @parauteur@ (@objet@ « @titre@ »).',
 	'forum_qui_etes_vous' => '<b>Nor zara ?</b> (aukerazkoa)',
 	'forum_saisie_texte_info' => 'Inprimaki honek Spip lasterbideak onartzen ditu <code>[-&gt;url] {{gizena}} {etzana} &lt;quote&gt; &lt;code&gt; </code> eta HTML kodeak <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Paragrafoak sortzeko, lerro bat hutsik utz.',
-	'forum_texte' => 'Zure mezuaren testua:',
+	'forum_texte' => 'Zure iruzkinaren testua:',
 	'forum_titre' => 'Izenburua',
-	'forum_url' => 'Zure gunea',
+	'forum_url' => 'Zure webgunea',
 	'forum_valider' => 'Aukera hori onartu',
 	'forum_voir_avant' => 'Aurreikusi',
 	'forum_votre_email' => 'Zure helbide elektronikoa',
@@ -89,6 +92,8 @@ Inskribaturik ez bazaude, aurretik inskribatu behar duzu.',
 	'info_desactiver_forum_public' => 'Foro publikoak desaktibatu. Puntualki aktiba daiteke artikuluendako artikuluetarako, baina ez berri-laburretarako edo ataletarako.',
 	'info_envoi_forum' => 'Foroen jarraipena',
 	'info_fonctionnement_forum' => 'Foroarenfuntzionamendua',
+	'info_forcer_previsualisation_court' => 'Aurreikuspena behartu',
+	'info_forcer_previsualisation_long' => 'Aurreikuspena behartu iruzkina bidali baino lehen',
 	'info_forums_liees_mot' => 'Hitz honi lotutako iruzkinak',
 	'info_gauche_suivi_forum_2' => 'Foroak jarraitzeko orrialdea zureguneko kudeaketa-tresna bat da (eta ez eztabaida edo idazketa-eremu bat). Guneko foroetako kontribuzio guztiak bistaratzen ditu, bai gune publikokoak bai eremu pribatukoak eta kontribuzio hauek administratzen uzten dizu.',
 	'info_liens_syndiques_3' => 'foroak',
@@ -124,7 +129,7 @@ Inskribaturik ez bazaude, aurretik inskribatu behar duzu.',
 	'lien_vider_selection' => 'Selekzioa hustu',
 
 	// M
-	'messages_aucun' => 'Batere',
+	'messages_aucun' => 'Bat ere ez',
 	'messages_meme_auteur' => 'Autore honen mezu guztiak',
 	'messages_meme_email' => 'Helbide elektroniko honen mezu guztia',
 	'messages_meme_ip' => 'IP helbide honen mezu guztiak',
@@ -171,5 +176,3 @@ Inskribaturik ez bazaude, aurretik inskribatu behar duzu.',
 	// V
 	'voir_messages_objet' => 'mezuak ikusi'
 );
-
-?>
