@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2016                                                *
+ *  Copyright (c) 2001-2019                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -16,7 +16,7 @@
  * @package SPIP\Medias\Renseigner
  **/
 
-if (!defined("_ECRIRE_INC_VERSION")) {
+if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
@@ -113,7 +113,6 @@ function renseigner_taille_dimension_image($fichier, $ext, $distant = false) {
 		or !@file_exists($fichier)
 		or !$infos['taille'] = @intval(filesize($fichier))
 	) {
-
 		if ($distant) {
 			// on ne saura pas la taille
 			unset($infos['taille']);
@@ -122,13 +121,13 @@ function renseigner_taille_dimension_image($fichier, $ext, $distant = false) {
 			$tmp = _DIR_TMP . md5($fichier);
 			$res = recuperer_url($fichier, array('file' => $tmp, 'taille_max' => 512 * 1024));
 			if (!$res) {
-				spip_log("Echec copie du fichier $fichier");
+				spip_log("Echec copie du fichier $fichier", 'medias');
 
 				return _T('medias:erreur_copie_fichier', array('nom' => $fichier));
 			}
 			$fichier = $tmp;
 		} else {
-			spip_log("Echec copie du fichier $fichier");
+			spip_log("Echec copie du fichier $fichier", 'medias');
 
 			return _T('medias:erreur_copie_fichier', array('nom' => $fichier));
 		}
@@ -136,17 +135,19 @@ function renseigner_taille_dimension_image($fichier, $ext, $distant = false) {
 
 	// chercher une fonction de description
 	$meta = array();
-	if ($metadata = charger_fonction($ext, "metadata", true)) {
+	if ($metadata = charger_fonction($ext, 'metadata', true)) {
 		$meta = $metadata($fichier);
 	} else {
 		$media = sql_getfetsel('media_defaut', 'spip_types_documents', 'extension=' . sql_quote($ext));
-		if ($metadata = charger_fonction($media, "metadata", true)) {
+		if ($metadata = charger_fonction($media, 'metadata', true)) {
 			$meta = $metadata($fichier);
 		}
 	}
 
-	$meta = pipeline('renseigner_document',
-		array('args' => array('extension' => $ext, 'fichier' => $fichier), 'data' => $meta));
+	$meta = pipeline(
+		'renseigner_document',
+		array('args' => array('extension' => $ext, 'fichier' => $fichier), 'data' => $meta)
+	);
 
 	include_spip('inc/filtres'); # pour objet_info()
 	$editables = objet_info('document', 'champs_editables');
