@@ -8,6 +8,9 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// A
+	'affichage_documents_en_cases' => 'Affichage en cases',
+	'affichage_documents_en_grand' => 'Affichage en grand',
+	'affichage_documents_en_liste_compacte' => 'Affichage en liste compacte',
 	'aucun_audio' => 'Aucune bande-son',
 	'aucun_document' => 'Aucun document',
 	'aucun_file' => 'Aucun document',
@@ -49,6 +52,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'des_utilisations' => '@nb@ utilisations',
 	'des_videos' => '@nb@ séquences',
 	'descriptif' => 'Description',
+	'details_document' => 'Détails',
+	'details_document_afficher_masquer' => 'Afficher / masquer les détails du document',
 	'document_attache_succes' => 'Le document a bien été ajouté',
 	'document_copie_locale_succes' => 'Le fichier a bien été copié dans le site',
 	'document_installe_succes' => 'Le fichier a bien été chargé',
@@ -69,14 +74,17 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_titre_image' => 'Titre de l’image :',
 	'erreur_aucun_document' => 'Ce document n’existe pas dans la médiathèque',
 	'erreur_aucun_fichier' => 'Aucun fichier n’a été trouvé',
+	'erreur_autorisation' => 'Échec de l’autorisation.',
 	'erreur_chemin_distant' => 'Le fichier distant @nom@ n’a pas pu être trouvé',
 	'erreur_chemin_ftp' => 'Le fichier indiqué n’a pas été trouvé sur le serveur',
 	'erreur_copie_fichier' => 'Impossible de copier le fichier @nom@',
+	'erreur_deplacement_impossible' => 'Déplacement impossible.',
 	'erreur_dossier_tmp_manquant' => 'Un dossier temporaire est manquant pour télécharger les fichiers',
 	'erreur_ecriture_fichier' => 'Erreur lors de l’écriture du fichier sur le disque',
 	'erreur_format_fichier_image' => 'Le format de @nom@ ne convient pas pour une image',
 	'erreur_indiquez_un_fichier' => 'Indiquez un fichier !',
 	'erreur_insertion_document_base' => 'Impossible d’enregistrer le document @fichier@ en base de données',
+	'erreur_objet_absent' => 'Informations reçues incomplètes.',
 	'erreur_suppression_vignette' => 'Erreur lors de la suppression de la vignette',
 	'erreur_upload_type_interdit' => 'Le téléchargement des fichiers du type de @nom@ n’est pas autorisé',
 	'erreur_upload_vignette' => 'Erreur lors du chargement de la vignette @nom@',
@@ -95,10 +103,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'image_tourner_180' => 'Rotation 180°',
 	'image_tourner_droite' => 'Rotation 90° à droite',
 	'image_tourner_gauche' => 'Rotation 90° à gauche',
+	'info_dimensions_image' => 'Dimensions',
 	'info_doc_max_poids' => 'Les documents doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
 	'info_document' => 'Document',
 	'info_document_indisponible' => 'Ce document n’est pas disponible',
 	'info_documents' => 'Documents',
+	'info_duree' => 'Durée',
 	'info_gauche_numero_document' => 'DOCUMENT NUMÉRO',
 	'info_hauteur' => 'Hauteur',
 	'info_heure' => 'Heure',
@@ -114,6 +124,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_modifier_document' => 'Modifier le document',
 	'info_portfolio' => 'Portfolio',
 	'info_referencer_doc_distant' => 'Référencer un document sur l’internet :',
+	'info_resolution_image' => 'Résolution',
+	'info_resolution_mpx' => '@resolution@ Mpx',
 	'info_sans_vignette' => 'Sans vignette',
 	'info_statut_document' => 'Ce document est :',
 	'info_taille' => 'Poids',
@@ -133,6 +145,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_paginer_par' => 'Paginer par :',
 	'label_parents' => 'Ce document est lié à',
 	'label_refdoc_joindre' => 'Document numéro',
+	'lien_tout_desordonner' => 'Réinitialiser l’ordre',
+	'lien_tout_desordonner_verif' => 'L’ordre définit pour cette liste de documents sera réinitialisé. Êtes-vous sûr ?',
 	'lien_tout_enlever' => 'Tout enlever',
 	'logo' => 'Logo',
 
@@ -150,6 +164,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// O
 	'objet_document' => 'Document',
 	'objet_documents' => 'Documents',
+	'ordonner_ce_document' => 'Ordonner ce document',
 
 	// P
 	'par_date' => 'Date',
@@ -192,5 +207,3 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'verifier_documents_inutilises' => 'Vérifier les liens des documents',
 	'vignette_supprimee' => 'La vignette a été supprimée'
 );
-
-?>
