@@ -7,7 +7,7 @@
  * @package SPIP\PortePlume\Pipelines
  **/
 
-if (!defined("_ECRIRE_INC_VERSION")) {
+if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
@@ -18,7 +18,8 @@ if (!defined("_ECRIRE_INC_VERSION")) {
  *
  * @pipeline autoriser
  */
-function porte_plume_autoriser() { }
+function porte_plume_autoriser() {
+}
 
 /**
  * Autoriser l'action de previsu
@@ -87,8 +88,8 @@ function porte_plume_insert_head_public($flux) {
  * @return string Contenu du head
  */
 function porte_plume_insert_head_prive($flux) {
-	$js = find_in_path('javascript/porte_plume_forcer_hauteur.js');
-	$flux = porte_plume_inserer_head($flux, $GLOBALS['spip_lang'], $prive = true)
+	$js = timestamp(find_in_path('javascript/porte_plume_forcer_hauteur.js'));
+	$flux = porte_plume_inserer_head($flux, $GLOBALS['spip_lang'], true)
 		. "<script type='text/javascript' src='$js'></script>\n";
 
 	return $flux;
@@ -103,12 +104,11 @@ function porte_plume_insert_head_prive($flux) {
  * @return string Contenu du head complété
  */
 function porte_plume_inserer_head($flux, $lang, $prive = false) {
-	$markitup = find_in_path('javascript/jquery.markitup_pour_spip.js');
-	$js_previsu = find_in_path('javascript/jquery.previsu_spip.js');
-	$js_start = parametre_url(generer_url_public('porte_plume_start.js'), 'lang', $lang);
-	if (defined('_VAR_MODE') and _VAR_MODE == "recalcul") {
-		$js_start = parametre_url($js_start, 'var_mode', 'recalcul');
-	}
+	$markitup = timestamp(find_in_path('javascript/jquery.markitup_pour_spip.js'));
+	$js_previsu = timestamp(find_in_path('javascript/jquery.previsu_spip.js'));
+
+	$hash = md5(porte_plume_creer_json_markitup());
+	$js_start = produire_fond_statique('javascript/porte_plume_start.js', array('lang' => $lang, 'hash' => $hash));
 
 	$flux .=
 		"<script type='text/javascript' src='$markitup'></script>\n"
@@ -144,14 +144,14 @@ function porte_plume_insert_head_css($flux = '', $prive = false) {
 	// toujours autoriser pour le prive.
 	if ($prive or autoriser('afficher_public', 'porteplume')) {
 		if ($prive) {
-			$cssprive = find_in_path('css/barre_outils_prive.css');
+			$cssprive = timestamp(find_in_path('css/barre_outils_prive.css'));
 			$flux .= "<link rel='stylesheet' type='text/css' media='all' href='$cssprive' />\n";
 		}
-		$css = direction_css(find_in_path('css/barre_outils.css'), lang_dir());
-		$css_icones = generer_url_public('barre_outils_icones.css');
-		if (defined('_VAR_MODE') and _VAR_MODE == "recalcul") {
-			$css_icones = parametre_url($css_icones, 'var_mode', 'recalcul');
-		}
+		$css = timestamp(direction_css(find_in_path('css/barre_outils.css'), lang_dir()));
+
+		$hash = md5(barre_outils_css_icones());
+		$css_icones = produire_fond_statique('css/barre_outils_icones.css', array('hash' => $hash));
+
 		$flux
 			.= "<link rel='stylesheet' type='text/css' media='all' href='$css' />\n"
 			. "<link rel='stylesheet' type='text/css' media='all' href='$css_icones' />\n";
@@ -185,8 +185,10 @@ function porte_plume_configurer_liste_metas($metas) {
  */
 function porte_plume_affiche_milieu($flux) {
 	if ($flux['args']['exec'] == 'configurer_avancees') {
-		$flux['data'] .= recuperer_fond('prive/squelettes/inclure/configurer',
-			array('configurer' => 'configurer_porte_plume'));
+		$flux['data'] .= recuperer_fond(
+			'prive/squelettes/inclure/configurer',
+			array('configurer' => 'configurer_porte_plume')
+		);
 	}
 
 	return $flux;
