@@ -3,14 +3,14 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2016                                                *
+ *  Copyright (c) 2001-2019                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
  *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
-if (!defined("_ECRIRE_INC_VERSION")) {
+if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
 
@@ -39,8 +39,9 @@ function afficher_diff_jointure_dist($champ, $old, $new, $format = 'diff') {
 	$intersection = array_intersect($new, $old);
 	foreach ($intersection as $id) {
 		if ($id = intval(trim($id))) {
-			$liste[$id] = "<a href='" . generer_url_entite($id, $objet) . "' title='" . _T(objet_info($objet,
-					'texte_objet')) . " $id'>" . generer_info_entite($id, $objet, 'titre') . "</a>";
+			$liste[$id] = "<a href='" . generer_url_entite($id, $objet) . "' title='" . _T(objet_info($objet, 'texte_objet')) . " $id'>"
+				. generer_info_entite($id, $objet, 'titre')
+				. '</a>';
 		}
 	}
 
@@ -49,9 +50,10 @@ function afficher_diff_jointure_dist($champ, $old, $new, $format = 'diff') {
 	foreach ($old as $id) {
 		if ($id = intval(trim($id))) {
 			$liste[$id] = "<span class='diff-supprime'>"
-				. "<a href='" . generer_url_entite($id, $objet) . "' title='" . _T(objet_info($objet,
-					'texte_objet')) . " $id'>" . generer_info_entite($id, $objet, 'titre') . "</a>"
-				. "</span>";
+				. "<a href='" . generer_url_entite($id, $objet) . "' title='" . _T(objet_info($objet, 'texte_objet')) . " $id'>"
+				. generer_info_entite($id, $objet, 'titre')
+				. '</a>'
+				. '</span>';
 		}
 	}
 
@@ -60,9 +62,10 @@ function afficher_diff_jointure_dist($champ, $old, $new, $format = 'diff') {
 	foreach ($new as $id) {
 		if ($id = intval(trim($id))) {
 			$liste[$id] = "<span class='diff-ajoute'>"
-				. "<a href='" . generer_url_entite($id, $objet) . "' title='" . _T(objet_info($objet,
-					'texte_objet')) . " $id'>" . generer_info_entite($id, $objet, 'titre') . "</a>"
-				. "</span>";
+				. "<a href='" . generer_url_entite($id, $objet) . "' title='" . _T(objet_info($objet, 'texte_objet')) . " $id'>"
+				. generer_info_entite($id, $objet, 'titre')
+				. '</a>'
+				. '</span>';
 		}
 	}
 
