@@ -1052,7 +1052,8 @@ class Decideur {
 				if ($p == 'SPIP') {
 					// c'est pas la que ça se fait !
 					// ca ne devrait plus apparaitre comme dependence a un plugin.
-				} // le core procure le paquet que l'on demande !
+				} 
+				// le core procure le paquet que l'on demande !
 				elseif (
 					array_key_exists($p, $this->procure)
 					and plugin_version_compatible($v, $this->procure[$p])
@@ -1122,11 +1123,7 @@ class Decideur {
 									$this->log("-- !erreur : $p");
 									// on ne trouve pas la dependance !
 									$this->invalider($info);
-									$this->erreur($id, $v ? _T('svp:message_dependance_plugin_version', array(
-										'plugin' => $info['n'],
-										'dependance' => $p,
-										'version' => $v
-									)) : _T('svp:message_dependance_plugin', array('plugin' => $info['n'], 'dependance' => $p)));
+									$this->erreur($id, $this->presenter_erreur_dependance($info, $p, $v));
 								}
 								unset($new, $vieux);
 								break;
@@ -1154,11 +1151,7 @@ class Decideur {
 									$this->log("-- !erreur : $p");
 									// on ne trouve pas la dependance !
 									$this->invalider($info);
-									$this->erreur($id, $v ? _T('svp:message_dependance_plugin_version', array(
-										'plugin' => $info['n'],
-										'dependance' => $p,
-										'version' => $v
-									)) : _T('svp:message_dependance_plugin', array('plugin' => $info['n'], 'dependance' => $p)));
+									$this->erreur($id, $this->presenter_erreur_dependance($info, $p, $v));
 								}
 								break;
 						}
@@ -1187,6 +1180,34 @@ class Decideur {
 		return true;
 	}
 
+	/**
+	 * Retourne le texte d'erreur adapté à une dépendance donnée
+	 */
+	public function presenter_erreur_dependance($info, $dependance, $intervalle) {
+		// prendre en compte les erreurs de dépendances à PHP
+		// ou à une extension PHP avec des messages d'erreurs dédiés.
+		$type = 'plugin';
+		if ($dependance === 'PHP') {
+			$type = 'php';
+		} elseif (strncmp($dependance, 'PHP:', 4) === 0) {
+			$type = 'extension_php';
+			list(,$dependance) = explode(':', $dependance, 2);
+		}
+
+		if ($intervalle) {
+			$info_dependance = svp_afficher_intervalle($intervalle, $dependance);
+		} else {
+			$info_dependance = $dependance;
+		}
+
+		$err = _T('svp:message_dependance_' . $type, array(
+			'plugin' => $info['n'],
+			'dependance' => $info_dependance,
+		));
+
+		return $err;
+	}
+
 	/**
 	 * Retourne un tableau des différentes actions qui seront faites
 	 *
