@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2016                                                *
+ *  Copyright (c) 2001-2019                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -65,6 +65,10 @@ function urls_upgrade($nom_meta_base_version, $version_cible) {
 		array('sql_alter', "table spip_urls ADD KEY langue (langue)"),
 	);
 
+	$maj['2.0.1'] = array(
+		array('sql_alter', "table spip_urls ADD KEY url (url)"),
+	);
+
 	include_spip('base/upgrade');
 	maj_plugin($nom_meta_base_version, $version_cible, $maj);
 }
